/********************************************************************************
** Form generated from reading UI file 'setupwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETUPWIDGET_H
#define UI_SETUPWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KPluralHandlingSpinBox"

QT_BEGIN_NAMESPACE

class Ui_SetupWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QStackedWidget *gameSetupStack;
    QWidget *newGamePage;
    QGridLayout *gridLayout_2;
    QLabel *label_12;
    QRadioButton *sizeSmall;
    QRadioButton *sizeMedium;
    QRadioButton *sizeBig;
    QHBoxLayout *horizontalLayout_4;
    QRadioButton *sizeOther;
    QSpinBox *sizeOtherSpinBox;
    QLabel *label_5;
    KPluralHandlingSpinBox *handicapSpinBox;
    QLabel *label_4;
    QDoubleSpinBox *komiSpinBox;
    QSpacerItem *verticalSpacer_5;
    QWidget *loadGamePage;
    QVBoxLayout *verticalLayout_3;
    QFrame *frame_2;
    QGridLayout *gridLayout;
    QLabel *eventStaticLabel;
    QLabel *eventLabel;
    QLabel *locationStaticLabel;
    QLabel *locationLabel;
    QLabel *dateStaticLabel;
    QLabel *dateLabel;
    QLabel *roundStaticLabel;
    QLabel *roundLabel;
    QLabel *scoreStaticLabel;
    QLabel *scoreLabel;
    QLabel *komiStaticLabel;
    QLabel *komiLabel;
    QLabel *continueStaticLabel;
    QLabel *playerLabel;
    QSpinBox *startMoveSpinBox;
    QLabel *timeStaticLabel;
    QLabel *timeLabel;
    QSpacerItem *verticalSpacer_6;
    QSpacerItem *verticalSpacer_4;
    QGridLayout *gridLayout_4;
    QSpacerItem *horizontalSpacer_2;
    QCheckBox *whiteIsComputerCheckBox;
    QStackedWidget *whitePlayerStack;
    QWidget *whiteHumanPage;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_6;
    QLineEdit *whitePlayerName;
    QWidget *whiteComputerPage;
    QGridLayout *gridLayout_8;
    QLabel *label1;
    QLabel *label2;
    QSlider *whiteStrengthSlider;
    QSpacerItem *verticalSpacer_2;
    QLabel *blackStoneImageLabel;
    QCheckBox *blackIsComputerCheckBox;
    QStackedWidget *blackPlayerStack;
    QWidget *blackHumanPage;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_7;
    QLineEdit *blackPlayerName;
    QWidget *blackComputerPage;
    QGridLayout *gridLayout_3;
    QLabel *label2_3;
    QLabel *label1_3;
    QSlider *blackStrengthSlider;
    QSpacerItem *verticalSpacer_3;
    QSpacerItem *verticalSpacer_7;
    QSpacerItem *verticalSpacer_8;
    QSpacerItem *verticalSpacer_9;
    QLabel *whiteStoneImageLabel;
    QSpacerItem *verticalSpacer_10;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *startButton;

    void setupUi(QWidget *SetupWidget)
    {
        if (SetupWidget->objectName().isEmpty())
            SetupWidget->setObjectName("SetupWidget");
        SetupWidget->resize(269, 598);
        verticalLayout_2 = new QVBoxLayout(SetupWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        gameSetupStack = new QStackedWidget(SetupWidget);
        gameSetupStack->setObjectName("gameSetupStack");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(gameSetupStack->sizePolicy().hasHeightForWidth());
        gameSetupStack->setSizePolicy(sizePolicy);
        newGamePage = new QWidget();
        newGamePage->setObjectName("newGamePage");
        gridLayout_2 = new QGridLayout(newGamePage);
        gridLayout_2->setObjectName("gridLayout_2");
        label_12 = new QLabel(newGamePage);
        label_12->setObjectName("label_12");

        gridLayout_2->addWidget(label_12, 0, 0, 1, 1);

        sizeSmall = new QRadioButton(newGamePage);
        sizeSmall->setObjectName("sizeSmall");
        sizeSmall->setChecked(true);

        gridLayout_2->addWidget(sizeSmall, 1, 0, 1, 2);

        sizeMedium = new QRadioButton(newGamePage);
        sizeMedium->setObjectName("sizeMedium");

        gridLayout_2->addWidget(sizeMedium, 2, 0, 1, 2);

        sizeBig = new QRadioButton(newGamePage);
        sizeBig->setObjectName("sizeBig");
        sizeBig->setChecked(false);

        gridLayout_2->addWidget(sizeBig, 3, 0, 1, 2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        sizeOther = new QRadioButton(newGamePage);
        sizeOther->setObjectName("sizeOther");

        horizontalLayout_4->addWidget(sizeOther);

        sizeOtherSpinBox = new QSpinBox(newGamePage);
        sizeOtherSpinBox->setObjectName("sizeOtherSpinBox");
        sizeOtherSpinBox->setEnabled(false);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(sizeOtherSpinBox->sizePolicy().hasHeightForWidth());
        sizeOtherSpinBox->setSizePolicy(sizePolicy1);
        sizeOtherSpinBox->setMinimum(5);
        sizeOtherSpinBox->setMaximum(19);
        sizeOtherSpinBox->setValue(19);

        horizontalLayout_4->addWidget(sizeOtherSpinBox);


        gridLayout_2->addLayout(horizontalLayout_4, 4, 0, 1, 2);

        label_5 = new QLabel(newGamePage);
        label_5->setObjectName("label_5");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy2);
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_5, 6, 0, 1, 1);

        handicapSpinBox = new KPluralHandlingSpinBox(newGamePage);
        handicapSpinBox->setObjectName("handicapSpinBox");
        handicapSpinBox->setEnabled(true);
        sizePolicy1.setHeightForWidth(handicapSpinBox->sizePolicy().hasHeightForWidth());
        handicapSpinBox->setSizePolicy(sizePolicy1);
        handicapSpinBox->setMinimum(1);
        handicapSpinBox->setMaximum(9);
        handicapSpinBox->setValue(4);

        gridLayout_2->addWidget(handicapSpinBox, 6, 1, 1, 1);

        label_4 = new QLabel(newGamePage);
        label_4->setObjectName("label_4");
        sizePolicy2.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy2);
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_4, 7, 0, 1, 1);

        komiSpinBox = new QDoubleSpinBox(newGamePage);
        komiSpinBox->setObjectName("komiSpinBox");
        sizePolicy1.setHeightForWidth(komiSpinBox->sizePolicy().hasHeightForWidth());
        komiSpinBox->setSizePolicy(sizePolicy1);
        komiSpinBox->setDecimals(1);
        komiSpinBox->setMaximum(50.000000000000000);
        komiSpinBox->setValue(4.500000000000000);

        gridLayout_2->addWidget(komiSpinBox, 7, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(verticalSpacer_5, 5, 0, 1, 1);

        gameSetupStack->addWidget(newGamePage);
        loadGamePage = new QWidget();
        loadGamePage->setObjectName("loadGamePage");
        verticalLayout_3 = new QVBoxLayout(loadGamePage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        frame_2 = new QFrame(loadGamePage);
        frame_2->setObjectName("frame_2");
        frame_2->setFrameShape(QFrame::NoFrame);
        frame_2->setFrameShadow(QFrame::Plain);
        gridLayout = new QGridLayout(frame_2);
        gridLayout->setObjectName("gridLayout");
        eventStaticLabel = new QLabel(frame_2);
        eventStaticLabel->setObjectName("eventStaticLabel");
        sizePolicy2.setHeightForWidth(eventStaticLabel->sizePolicy().hasHeightForWidth());
        eventStaticLabel->setSizePolicy(sizePolicy2);
        eventStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(eventStaticLabel, 0, 0, 1, 1);

        eventLabel = new QLabel(frame_2);
        eventLabel->setObjectName("eventLabel");
        sizePolicy2.setHeightForWidth(eventLabel->sizePolicy().hasHeightForWidth());
        eventLabel->setSizePolicy(sizePolicy2);
        eventLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        eventLabel->setWordWrap(true);

        gridLayout->addWidget(eventLabel, 0, 1, 1, 1);

        locationStaticLabel = new QLabel(frame_2);
        locationStaticLabel->setObjectName("locationStaticLabel");
        sizePolicy2.setHeightForWidth(locationStaticLabel->sizePolicy().hasHeightForWidth());
        locationStaticLabel->setSizePolicy(sizePolicy2);
        locationStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(locationStaticLabel, 1, 0, 1, 1);

        locationLabel = new QLabel(frame_2);
        locationLabel->setObjectName("locationLabel");
        sizePolicy2.setHeightForWidth(locationLabel->sizePolicy().hasHeightForWidth());
        locationLabel->setSizePolicy(sizePolicy2);
        locationLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        locationLabel->setWordWrap(true);

        gridLayout->addWidget(locationLabel, 1, 1, 1, 1);

        dateStaticLabel = new QLabel(frame_2);
        dateStaticLabel->setObjectName("dateStaticLabel");
        sizePolicy2.setHeightForWidth(dateStaticLabel->sizePolicy().hasHeightForWidth());
        dateStaticLabel->setSizePolicy(sizePolicy2);
        dateStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(dateStaticLabel, 2, 0, 1, 1);

        dateLabel = new QLabel(frame_2);
        dateLabel->setObjectName("dateLabel");
        sizePolicy2.setHeightForWidth(dateLabel->sizePolicy().hasHeightForWidth());
        dateLabel->setSizePolicy(sizePolicy2);
        dateLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(dateLabel, 2, 1, 1, 1);

        roundStaticLabel = new QLabel(frame_2);
        roundStaticLabel->setObjectName("roundStaticLabel");
        sizePolicy2.setHeightForWidth(roundStaticLabel->sizePolicy().hasHeightForWidth());
        roundStaticLabel->setSizePolicy(sizePolicy2);
        roundStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(roundStaticLabel, 3, 0, 1, 1);

        roundLabel = new QLabel(frame_2);
        roundLabel->setObjectName("roundLabel");
        sizePolicy2.setHeightForWidth(roundLabel->sizePolicy().hasHeightForWidth());
        roundLabel->setSizePolicy(sizePolicy2);
        roundLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(roundLabel, 3, 1, 1, 1);

        scoreStaticLabel = new QLabel(frame_2);
        scoreStaticLabel->setObjectName("scoreStaticLabel");
        sizePolicy2.setHeightForWidth(scoreStaticLabel->sizePolicy().hasHeightForWidth());
        scoreStaticLabel->setSizePolicy(sizePolicy2);
        scoreStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(scoreStaticLabel, 4, 0, 1, 1);

        scoreLabel = new QLabel(frame_2);
        scoreLabel->setObjectName("scoreLabel");
        sizePolicy2.setHeightForWidth(scoreLabel->sizePolicy().hasHeightForWidth());
        scoreLabel->setSizePolicy(sizePolicy2);
        scoreLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(scoreLabel, 4, 1, 1, 1);

        komiStaticLabel = new QLabel(frame_2);
        komiStaticLabel->setObjectName("komiStaticLabel");
        sizePolicy2.setHeightForWidth(komiStaticLabel->sizePolicy().hasHeightForWidth());
        komiStaticLabel->setSizePolicy(sizePolicy2);
        komiStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(komiStaticLabel, 5, 0, 1, 1);

        komiLabel = new QLabel(frame_2);
        komiLabel->setObjectName("komiLabel");
        sizePolicy2.setHeightForWidth(komiLabel->sizePolicy().hasHeightForWidth());
        komiLabel->setSizePolicy(sizePolicy2);
        komiLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(komiLabel, 5, 1, 1, 1);

        continueStaticLabel = new QLabel(frame_2);
        continueStaticLabel->setObjectName("continueStaticLabel");
        sizePolicy2.setHeightForWidth(continueStaticLabel->sizePolicy().hasHeightForWidth());
        continueStaticLabel->setSizePolicy(sizePolicy2);
        continueStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(continueStaticLabel, 7, 0, 1, 1);

        playerLabel = new QLabel(frame_2);
        playerLabel->setObjectName("playerLabel");

        gridLayout->addWidget(playerLabel, 9, 1, 1, 1);

        startMoveSpinBox = new QSpinBox(frame_2);
        startMoveSpinBox->setObjectName("startMoveSpinBox");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(startMoveSpinBox->sizePolicy().hasHeightForWidth());
        startMoveSpinBox->setSizePolicy(sizePolicy3);
        startMoveSpinBox->setAccelerated(true);
        startMoveSpinBox->setCorrectionMode(QAbstractSpinBox::CorrectToNearestValue);
        startMoveSpinBox->setMinimum(1);
        startMoveSpinBox->setMaximum(9999);

        gridLayout->addWidget(startMoveSpinBox, 7, 1, 1, 1);

        timeStaticLabel = new QLabel(frame_2);
        timeStaticLabel->setObjectName("timeStaticLabel");
        sizePolicy2.setHeightForWidth(timeStaticLabel->sizePolicy().hasHeightForWidth());
        timeStaticLabel->setSizePolicy(sizePolicy2);
        timeStaticLabel->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(timeStaticLabel, 6, 0, 1, 1);

        timeLabel = new QLabel(frame_2);
        timeLabel->setObjectName("timeLabel");
        sizePolicy2.setHeightForWidth(timeLabel->sizePolicy().hasHeightForWidth());
        timeLabel->setSizePolicy(sizePolicy2);
        timeLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(timeLabel, 6, 1, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(verticalSpacer_6, 10, 1, 1, 1);


        verticalLayout_3->addWidget(frame_2);

        gameSetupStack->addWidget(loadGamePage);

        verticalLayout_2->addWidget(gameSetupStack);

        verticalSpacer_4 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        verticalLayout_2->addItem(verticalSpacer_4);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setObjectName("gridLayout_4");
        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacer_2, 4, 0, 1, 1);

        whiteIsComputerCheckBox = new QCheckBox(SetupWidget);
        whiteIsComputerCheckBox->setObjectName("whiteIsComputerCheckBox");

        gridLayout_4->addWidget(whiteIsComputerCheckBox, 4, 2, 1, 1);

        whitePlayerStack = new QStackedWidget(SetupWidget);
        whitePlayerStack->setObjectName("whitePlayerStack");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(whitePlayerStack->sizePolicy().hasHeightForWidth());
        whitePlayerStack->setSizePolicy(sizePolicy4);
        whitePlayerStack->setFrameShape(QFrame::NoFrame);
        whiteHumanPage = new QWidget();
        whiteHumanPage->setObjectName("whiteHumanPage");
        horizontalLayout_2 = new QHBoxLayout(whiteHumanPage);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_6 = new QLabel(whiteHumanPage);
        label_6->setObjectName("label_6");

        horizontalLayout_2->addWidget(label_6);

        whitePlayerName = new QLineEdit(whiteHumanPage);
        whitePlayerName->setObjectName("whitePlayerName");
        whitePlayerName->setEnabled(true);

        horizontalLayout_2->addWidget(whitePlayerName);

        whitePlayerStack->addWidget(whiteHumanPage);
        whiteComputerPage = new QWidget();
        whiteComputerPage->setObjectName("whiteComputerPage");
        gridLayout_8 = new QGridLayout(whiteComputerPage);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setContentsMargins(0, 0, 0, 0);
        label1 = new QLabel(whiteComputerPage);
        label1->setObjectName("label1");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(label1->sizePolicy().hasHeightForWidth());
        label1->setSizePolicy(sizePolicy5);
        label1->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_8->addWidget(label1, 0, 0, 1, 1);

        label2 = new QLabel(whiteComputerPage);
        label2->setObjectName("label2");
        sizePolicy5.setHeightForWidth(label2->sizePolicy().hasHeightForWidth());
        label2->setSizePolicy(sizePolicy5);
        label2->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_8->addWidget(label2, 0, 3, 1, 1);

        whiteStrengthSlider = new QSlider(whiteComputerPage);
        whiteStrengthSlider->setObjectName("whiteStrengthSlider");
        whiteStrengthSlider->setMinimum(1);
        whiteStrengthSlider->setMaximum(10);
        whiteStrengthSlider->setPageStep(1);
        whiteStrengthSlider->setValue(5);
        whiteStrengthSlider->setOrientation(Qt::Horizontal);
        whiteStrengthSlider->setTickPosition(QSlider::TicksBelow);
        whiteStrengthSlider->setTickInterval(0);

        gridLayout_8->addWidget(whiteStrengthSlider, 0, 1, 1, 1);

        whitePlayerStack->addWidget(whiteComputerPage);

        gridLayout_4->addWidget(whitePlayerStack, 5, 2, 2, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_2, 7, 2, 1, 1);

        blackStoneImageLabel = new QLabel(SetupWidget);
        blackStoneImageLabel->setObjectName("blackStoneImageLabel");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(blackStoneImageLabel->sizePolicy().hasHeightForWidth());
        blackStoneImageLabel->setSizePolicy(sizePolicy6);
        blackStoneImageLabel->setMinimumSize(QSize(48, 48));
        blackStoneImageLabel->setMaximumSize(QSize(48, 48));
        blackStoneImageLabel->setFrameShape(QFrame::NoFrame);

        gridLayout_4->addWidget(blackStoneImageLabel, 8, 1, 3, 1);

        blackIsComputerCheckBox = new QCheckBox(SetupWidget);
        blackIsComputerCheckBox->setObjectName("blackIsComputerCheckBox");

        gridLayout_4->addWidget(blackIsComputerCheckBox, 9, 2, 1, 1);

        blackPlayerStack = new QStackedWidget(SetupWidget);
        blackPlayerStack->setObjectName("blackPlayerStack");
        sizePolicy2.setHeightForWidth(blackPlayerStack->sizePolicy().hasHeightForWidth());
        blackPlayerStack->setSizePolicy(sizePolicy2);
        blackHumanPage = new QWidget();
        blackHumanPage->setObjectName("blackHumanPage");
        horizontalLayout_3 = new QHBoxLayout(blackHumanPage);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_7 = new QLabel(blackHumanPage);
        label_7->setObjectName("label_7");

        horizontalLayout_3->addWidget(label_7);

        blackPlayerName = new QLineEdit(blackHumanPage);
        blackPlayerName->setObjectName("blackPlayerName");
        blackPlayerName->setEnabled(true);

        horizontalLayout_3->addWidget(blackPlayerName);

        blackPlayerStack->addWidget(blackHumanPage);
        blackComputerPage = new QWidget();
        blackComputerPage->setObjectName("blackComputerPage");
        gridLayout_3 = new QGridLayout(blackComputerPage);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        label2_3 = new QLabel(blackComputerPage);
        label2_3->setObjectName("label2_3");
        sizePolicy5.setHeightForWidth(label2_3->sizePolicy().hasHeightForWidth());
        label2_3->setSizePolicy(sizePolicy5);
        label2_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout_3->addWidget(label2_3, 0, 4, 1, 1);

        label1_3 = new QLabel(blackComputerPage);
        label1_3->setObjectName("label1_3");
        sizePolicy5.setHeightForWidth(label1_3->sizePolicy().hasHeightForWidth());
        label1_3->setSizePolicy(sizePolicy5);
        label1_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_3->addWidget(label1_3, 0, 2, 1, 1);

        blackStrengthSlider = new QSlider(blackComputerPage);
        blackStrengthSlider->setObjectName("blackStrengthSlider");
        blackStrengthSlider->setMinimum(1);
        blackStrengthSlider->setMaximum(10);
        blackStrengthSlider->setPageStep(1);
        blackStrengthSlider->setValue(5);
        blackStrengthSlider->setOrientation(Qt::Horizontal);
        blackStrengthSlider->setTickPosition(QSlider::TicksBelow);
        blackStrengthSlider->setTickInterval(0);

        gridLayout_3->addWidget(blackStrengthSlider, 0, 3, 1, 1);

        blackPlayerStack->addWidget(blackComputerPage);

        gridLayout_4->addWidget(blackPlayerStack, 10, 2, 2, 1);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_3, 12, 2, 1, 1);

        verticalSpacer_7 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(verticalSpacer_7, 6, 1, 1, 1);

        verticalSpacer_8 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(verticalSpacer_8, 11, 1, 1, 1);

        verticalSpacer_9 = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_9, 3, 2, 1, 1);

        whiteStoneImageLabel = new QLabel(SetupWidget);
        whiteStoneImageLabel->setObjectName("whiteStoneImageLabel");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(whiteStoneImageLabel->sizePolicy().hasHeightForWidth());
        whiteStoneImageLabel->setSizePolicy(sizePolicy7);
        whiteStoneImageLabel->setMinimumSize(QSize(48, 48));
        whiteStoneImageLabel->setMaximumSize(QSize(48, 48));
        whiteStoneImageLabel->setFrameShape(QFrame::NoFrame);

        gridLayout_4->addWidget(whiteStoneImageLabel, 3, 1, 3, 1);

        verticalSpacer_10 = new QSpacerItem(20, 4, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout_4->addItem(verticalSpacer_10, 8, 2, 1, 1);


        verticalLayout_2->addLayout(gridLayout_4);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        startButton = new QPushButton(SetupWidget);
        startButton->setObjectName("startButton");

        horizontalLayout->addWidget(startButton);


        verticalLayout_2->addLayout(horizontalLayout);

#if QT_CONFIG(shortcut)
        label_5->setBuddy(handicapSpinBox);
        label_4->setBuddy(komiSpinBox);
        continueStaticLabel->setBuddy(startMoveSpinBox);
        label_6->setBuddy(whitePlayerName);
        label1->setBuddy(whiteStrengthSlider);
        label2->setBuddy(whiteStrengthSlider);
        label_7->setBuddy(blackPlayerName);
        label2_3->setBuddy(blackStrengthSlider);
        label1_3->setBuddy(blackStrengthSlider);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(whitePlayerName, whiteStrengthSlider);
        QWidget::setTabOrder(whiteStrengthSlider, blackPlayerName);
        QWidget::setTabOrder(blackPlayerName, blackStrengthSlider);

        retranslateUi(SetupWidget);

        gameSetupStack->setCurrentIndex(0);
        whitePlayerStack->setCurrentIndex(0);
        blackPlayerStack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SetupWidget);
    } // setupUi

    void retranslateUi(QWidget *SetupWidget)
    {
        label_12->setText(tr2i18n("Board size:", nullptr));
        sizeSmall->setText(tr2i18n("&Tiny (9x9)", nullptr));
        sizeMedium->setText(tr2i18n("Small (&13x13)", nullptr));
        sizeBig->setText(tr2i18n("No&rmal (19x19)", nullptr));
        sizeOther->setText(tr2i18n("&Custom:", nullptr));
        label_5->setText(tr2i18n("Handicap:", nullptr));
#if QT_CONFIG(tooltip)
        handicapSpinBox->setToolTip(tr2i18n("Handicap stones are an advantage for the black player.\n"
"Black gets a number of stones on the board before the game starts.", nullptr));
#endif // QT_CONFIG(tooltip)
        handicapSpinBox->setSpecialValueText(tr2i18n("No handicap", nullptr));
        label_4->setText(tr2i18n("Komi:", nullptr));
#if QT_CONFIG(tooltip)
        komiSpinBox->setToolTip(tr2i18n("Komi are points given to the white player at the end of the game.\n"
"It balances out the advantage black has by making the first move.", nullptr));
#endif // QT_CONFIG(tooltip)
        komiSpinBox->setSuffix(tr2i18n(" Points", nullptr));
        eventStaticLabel->setText(tr2i18n("Event:", nullptr));
        eventLabel->setText(QString());
        locationStaticLabel->setText(tr2i18n("Location:", nullptr));
        locationLabel->setText(QString());
        dateStaticLabel->setText(tr2i18n("Date:", nullptr));
        dateLabel->setText(QString());
        roundStaticLabel->setText(tr2i18n("Round:", nullptr));
        roundLabel->setText(QString());
        scoreStaticLabel->setText(tr2i18n("Score:", nullptr));
        scoreLabel->setText(QString());
        komiStaticLabel->setText(tr2i18n("Komi:", nullptr));
        komiLabel->setText(QString());
        continueStaticLabel->setText(tr2i18n("Continue:", nullptr));
        playerLabel->setText(tr2i18n("Black to play", nullptr));
        startMoveSpinBox->setSuffix(tr2i18n(" of 999", nullptr));
        startMoveSpinBox->setPrefix(tr2i18n("Move ", nullptr));
        timeStaticLabel->setText(tr2i18n("Time limit:", nullptr));
        timeLabel->setText(QString());
        whiteIsComputerCheckBox->setText(tr2i18n("&Computer", nullptr));
        label_6->setText(tr2i18n("&Name:", nullptr));
        whitePlayerName->setText(QString());
        label1->setText(tr2i18n("Weak", nullptr));
        label2->setText(tr2i18n("Strong", nullptr));
        blackStoneImageLabel->setText(QString());
        blackIsComputerCheckBox->setText(tr2i18n("C&omputer", nullptr));
        label_7->setText(tr2i18n("Na&me:", nullptr));
        blackPlayerName->setText(QString());
        label2_3->setText(tr2i18n("Strong", nullptr));
        label1_3->setText(tr2i18n("Weak", nullptr));
        whiteStoneImageLabel->setText(QString());
        startButton->setText(tr2i18n("Start Game", nullptr));
        (void)SetupWidget;
    } // retranslateUi

};

namespace Ui {
    class SetupWidget: public Ui_SetupWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETUPWIDGET_H

