/****************************************************************************
** Meta object code from reading C++ file 'game.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kigo-26.04.0/src/game/game.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'game.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4Kigo4GameE_t {};
} // unnamed namespace

template <> constexpr inline auto Kigo::Game::qt_create_metaobjectdata<qt_meta_tag_ZN4Kigo4GameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Kigo::Game",
        "boardInitialized",
        "",
        "boardChanged",
        "boardSizeChanged",
        "resigned",
        "Kigo::Player",
        "passMovePlayed",
        "consecutivePassMovesPlayed",
        "currentPlayerChanged",
        "waiting",
        "canRedoChanged",
        "canUndoChanged",
        "gameSetup",
        "waitResponse",
        "nonBlocking",
        "readyRead",
        "undoIndexChanged",
        "index"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'boardInitialized'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boardChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'boardSizeChanged'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'resigned'
        QtMocHelpers::SignalData<void(const Kigo::Player &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'passMovePlayed'
        QtMocHelpers::SignalData<void(const Kigo::Player &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'consecutivePassMovesPlayed'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'currentPlayerChanged'
        QtMocHelpers::SignalData<void(const Kigo::Player &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'waiting'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'canRedoChanged'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'canUndoChanged'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'gameSetup'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'waitResponse'
        QtMocHelpers::SlotData<bool(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'waitResponse'
        QtMocHelpers::SlotData<bool()>(14, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'readyRead'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'undoIndexChanged'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Game, qt_meta_tag_ZN4Kigo4GameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Kigo::Game::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kigo4GameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kigo4GameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4Kigo4GameE_t>.metaTypes,
    nullptr
} };

void Kigo::Game::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Game *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->boardInitialized(); break;
        case 1: _t->boardChanged(); break;
        case 2: _t->boardSizeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->resigned((*reinterpret_cast<std::add_pointer_t<Kigo::Player>>(_a[1]))); break;
        case 4: _t->passMovePlayed((*reinterpret_cast<std::add_pointer_t<Kigo::Player>>(_a[1]))); break;
        case 5: _t->consecutivePassMovesPlayed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->currentPlayerChanged((*reinterpret_cast<std::add_pointer_t<Kigo::Player>>(_a[1]))); break;
        case 7: _t->waiting((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 8: _t->canRedoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->canUndoChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 10: _t->gameSetup(); break;
        case 11: { bool _r = _t->waitResponse((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->waitResponse();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->readyRead(); break;
        case 14: _t->undoIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Game::*)()>(_a, &Game::boardInitialized, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)()>(_a, &Game::boardChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(int )>(_a, &Game::boardSizeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(const Kigo::Player & )>(_a, &Game::resigned, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(const Kigo::Player & )>(_a, &Game::passMovePlayed, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(int )>(_a, &Game::consecutivePassMovesPlayed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(const Kigo::Player & )>(_a, &Game::currentPlayerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(bool )>(_a, &Game::waiting, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(bool )>(_a, &Game::canRedoChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Game::*)(bool )>(_a, &Game::canUndoChanged, 9))
            return;
    }
}

const QMetaObject *Kigo::Game::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Kigo::Game::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4Kigo4GameE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Kigo::Game::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void Kigo::Game::boardInitialized()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Kigo::Game::boardChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Kigo::Game::boardSizeChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void Kigo::Game::resigned(const Kigo::Player & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Kigo::Game::passMovePlayed(const Kigo::Player & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Kigo::Game::consecutivePassMovesPlayed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Kigo::Game::currentPlayerChanged(const Kigo::Player & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Kigo::Game::waiting(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void Kigo::Game::canRedoChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void Kigo::Game::canUndoChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}
QT_WARNING_POP
