/********************************************************************************
** Form generated from reading UI file 'generalconfig.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GENERALCONFIG_H
#define UI_GENERALCONFIG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kled.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_GeneralConfig
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *backendGroupBox;
    QGridLayout *gridLayout;
    QLabel *label_3;
    KUrlRequester *engineExecutable;
    QLabel *label;
    QLineEdit *engineParameters;
    QLineEdit *kcfg_EngineCommand;
    KLed *engineLed;
    QLabel *label_4;
    QFrame *line_2;
    QGroupBox *appearanceGroupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_ShowBoardLabels;
    QLabel *label_2;
    QDoubleSpinBox *kcfg_HintVisibleTime;
    QFrame *line;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *GeneralConfig)
    {
        if (GeneralConfig->objectName().isEmpty())
            GeneralConfig->setObjectName("GeneralConfig");
        GeneralConfig->resize(361, 406);
        verticalLayout_2 = new QVBoxLayout(GeneralConfig);
        verticalLayout_2->setObjectName("verticalLayout_2");
        backendGroupBox = new QGroupBox(GeneralConfig);
        backendGroupBox->setObjectName("backendGroupBox");
        gridLayout = new QGridLayout(backendGroupBox);
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(backendGroupBox);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        engineExecutable = new KUrlRequester(backendGroupBox);
        engineExecutable->setObjectName("engineExecutable");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(engineExecutable->sizePolicy().hasHeightForWidth());
        engineExecutable->setSizePolicy(sizePolicy);

        gridLayout->addWidget(engineExecutable, 2, 1, 1, 2);

        label = new QLabel(backendGroupBox);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 3, 0, 1, 1);

        engineParameters = new QLineEdit(backendGroupBox);
        engineParameters->setObjectName("engineParameters");

        gridLayout->addWidget(engineParameters, 3, 1, 1, 1);

        kcfg_EngineCommand = new QLineEdit(backendGroupBox);
        kcfg_EngineCommand->setObjectName("kcfg_EngineCommand");
        kcfg_EngineCommand->setEnabled(false);
        kcfg_EngineCommand->setFocusPolicy(Qt::NoFocus);
        kcfg_EngineCommand->setReadOnly(true);

        gridLayout->addWidget(kcfg_EngineCommand, 4, 1, 1, 2);

        engineLed = new KLed(backendGroupBox);
        engineLed->setObjectName("engineLed");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(engineLed->sizePolicy().hasHeightForWidth());
        engineLed->setSizePolicy(sizePolicy1);
        engineLed->setState(KLed::Off);

        gridLayout->addWidget(engineLed, 3, 2, 1, 1);

        label_4 = new QLabel(backendGroupBox);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        gridLayout->addWidget(label_4, 0, 0, 1, 3);

        line_2 = new QFrame(backendGroupBox);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout->addWidget(line_2, 1, 0, 1, 3);


        verticalLayout_2->addWidget(backendGroupBox);

        appearanceGroupBox = new QGroupBox(GeneralConfig);
        appearanceGroupBox->setObjectName("appearanceGroupBox");
        appearanceGroupBox->setCheckable(false);
        gridLayout_2 = new QGridLayout(appearanceGroupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_ShowBoardLabels = new QCheckBox(appearanceGroupBox);
        kcfg_ShowBoardLabels->setObjectName("kcfg_ShowBoardLabels");

        gridLayout_2->addWidget(kcfg_ShowBoardLabels, 0, 0, 1, 2);

        label_2 = new QLabel(appearanceGroupBox);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout_2->addWidget(label_2, 4, 0, 1, 1);

        kcfg_HintVisibleTime = new QDoubleSpinBox(appearanceGroupBox);
        kcfg_HintVisibleTime->setObjectName("kcfg_HintVisibleTime");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(kcfg_HintVisibleTime->sizePolicy().hasHeightForWidth());
        kcfg_HintVisibleTime->setSizePolicy(sizePolicy2);
        kcfg_HintVisibleTime->setDecimals(1);
        kcfg_HintVisibleTime->setMinimum(1.000000000000000);
        kcfg_HintVisibleTime->setMaximum(10.000000000000000);
        kcfg_HintVisibleTime->setSingleStep(0.500000000000000);
        kcfg_HintVisibleTime->setValue(3.000000000000000);

        gridLayout_2->addWidget(kcfg_HintVisibleTime, 4, 1, 1, 1);

        line = new QFrame(appearanceGroupBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line, 3, 0, 1, 2);


        verticalLayout_2->addWidget(appearanceGroupBox);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

#if QT_CONFIG(shortcut)
        label_3->setBuddy(engineExecutable);
        label->setBuddy(engineParameters);
        label_2->setBuddy(kcfg_HintVisibleTime);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(kcfg_ShowBoardLabels, kcfg_HintVisibleTime);

        retranslateUi(GeneralConfig);

        QMetaObject::connectSlotsByName(GeneralConfig);
    } // setupUi

    void retranslateUi(QWidget *GeneralConfig)
    {
        backendGroupBox->setTitle(tr2i18n("Backend", nullptr));
        label_3->setText(tr2i18n("Executable:", nullptr));
#if QT_CONFIG(tooltip)
        engineExecutable->setToolTip(tr2i18n("Select the executable file to start the Go engine", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Parameters:", nullptr));
#if QT_CONFIG(tooltip)
        engineParameters->setToolTip(tr2i18n("Add here the necessary parameters to start the Engine in GTP mode", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        kcfg_EngineCommand->setToolTip(tr2i18n("This is the resulting engine command which will be used by Kigo", nullptr));
#endif // QT_CONFIG(tooltip)
        kcfg_EngineCommand->setText(QString());
#if QT_CONFIG(tooltip)
        engineLed->setToolTip(tr2i18n("Indicates whether the Go engine works correctly", nullptr));
#endif // QT_CONFIG(tooltip)
        label_4->setText(tr2i18n("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Sans Serif'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\">Please select a Go engine that supports the <span style=\" font-style:italic;\">GnuGo Text Protocol (GTP)</span>. The indicator light turns green when the selected backend is working.</p></body></html>", nullptr));
        appearanceGroupBox->setTitle(tr2i18n("Appearance", nullptr));
        kcfg_ShowBoardLabels->setText(tr2i18n("Display Board Labels", nullptr));
        label_2->setText(tr2i18n("Hint Visibility Time:", nullptr));
        kcfg_HintVisibleTime->setSuffix(tr2i18n(" Seconds", nullptr));
        (void)GeneralConfig;
    } // retranslateUi

};

namespace Ui {
    class GeneralConfig: public Ui_GeneralConfig {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GENERALCONFIG_H

