/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 6.11.0
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#ifdef _MSC_VER
// disable informational message "function ... selected for automatic inline expansion"
#pragma warning (disable: 4711)
#endif

static const unsigned char qt_resource_data[] = {
  // kigoui.rc
  0x0,0x0,0x1,0xfd,
  0x28,
  0xb5,0x2f,0xfd,0x60,0x83,0x6,0x9d,0xf,0x0,0xb6,0xd6,0x44,0x1e,0x30,0x91,0x1b,
  0x9d,0xcf,0x1c,0x13,0x53,0x23,0x6d,0xc9,0x3a,0xeb,0x25,0xd2,0x78,0xd8,0x41,0x44,
  0xfb,0x19,0x39,0x58,0x83,0x42,0x21,0x22,0x8a,0xb,0x61,0x3d,0x0,0x3e,0x0,0x3a,
  0x0,0x13,0x4a,0x85,0xad,0x3f,0x5f,0x94,0x2e,0x58,0x88,0x11,0x64,0x59,0xf6,0x1e,
  0xe2,0xfa,0xaf,0x1c,0x34,0xbb,0x39,0xce,0xe0,0x3c,0x32,0xc6,0x41,0x6b,0x69,0x37,
  0xc6,0xe2,0xe3,0x44,0xa,0x77,0x8,0x3c,0x26,0x14,0x7,0xc5,0x66,0xe8,0x54,0x6f,
  0x73,0x3,0x1,0xc1,0x41,0xed,0x3c,0xe5,0x6a,0x5a,0xc6,0xda,0x28,0x9e,0x89,0xcb,
  0x52,0x40,0xe4,0xb0,0x5e,0xb,0xb1,0x99,0xe7,0x5f,0x38,0xa8,0x9d,0x6a,0xbf,0xd9,
  0x5f,0x4b,0xa3,0xd4,0x6,0xd6,0x2b,0x3d,0x91,0x83,0x73,0x23,0x68,0x4e,0x3b,0xbf,
  0x52,0x1e,0x99,0x8,0x9e,0x4b,0x35,0x7,0xd4,0xda,0x8a,0x92,0x44,0xa4,0xca,0x23,
  0xc,0x6,0x5,0x43,0xc6,0x73,0x83,0x78,0x8c,0x45,0xcc,0xb,0xbd,0xd7,0xa5,0xd,
  0x43,0x39,0x94,0xcc,0xd8,0xfc,0xbf,0x53,0xae,0xc5,0xc2,0xfa,0xb9,0x6f,0xae,0x26,
  0x8d,0x4b,0x1a,0xb7,0xde,0x33,0x5f,0xb7,0x9a,0xdc,0x7c,0x79,0xa9,0x2f,0xfd,0x55,
  0xea,0xb5,0x92,0xd5,0xe8,0x9c,0xd3,0x4a,0xb7,0xa6,0x5f,0xa8,0x9e,0x79,0x2e,0xdb,
  0x9e,0x28,0xc6,0x7b,0x20,0x1,0x4e,0xc4,0x58,0x7c,0x4f,0x4b,0xec,0x27,0xd8,0xbb,
  0xf2,0x39,0x87,0x8d,0x45,0xef,0x91,0x6a,0x69,0xcd,0x2a,0x39,0x91,0xfb,0x2a,0xb2,
  0xe4,0x49,0x3b,0xc5,0xcd,0x11,0xa2,0x5c,0xc9,0xbb,0xb9,0x66,0xcd,0xb8,0x4f,0xe6,
  0x73,0x99,0x6d,0xbd,0xa6,0xb,0xfb,0x9d,0x8e,0x28,0xd7,0x9a,0x32,0xaf,0x60,0x5d,
  0xa0,0xc1,0x15,0x43,0x90,0x90,0xa4,0xa2,0x4a,0x61,0x1a,0x3,0x30,0x84,0x10,0x43,
  0x1d,0x75,0x3,0x4b,0xc4,0xf9,0x5d,0xc8,0xc7,0x4f,0xfe,0x73,0xdb,0x4f,0x8c,0x48,
  0x72,0x8b,0x3,0x26,0xaf,0x92,0xeb,0x3a,0xb9,0x1e,0xb8,0x55,0xcb,0xfb,0x28,0x5b,
  0x6f,0xf,0x9a,0xad,0xba,0xa6,0xbb,0xa4,0x78,0x37,0xc9,0x3,0x89,0x44,0xb2,0xb8,
  0xd9,0xd2,0x4a,0x27,0xd1,0x72,0xa7,0x91,0x17,0x96,0x3,0x4e,0x2d,0x8b,0x36,0x2,
  0x32,0x1,0x3e,0x40,0x2f,0xe9,0x39,0x38,0x9b,0xfb,0xc9,0x61,0x3d,0xdd,0x8b,0x25,
  0xb5,0xed,0x67,0x65,0xd5,0x5e,0x97,0x99,0x13,0xd1,0x73,0xcf,0x92,0x16,0xd2,0x1,
  0xf9,0xc5,0xdc,0x49,0xf,0x2c,0x49,0xc0,0x38,0x3a,0x30,0x6e,0x7b,0x59,0xe2,0x69,
  0x34,0x70,0x40,0xbb,0x72,0x74,0xbc,0x46,0x40,0xb2,0x88,0x64,0x52,0x5f,0x91,0x0,
  0x2b,0x1c,0x4e,0x9,0x9,0xeb,0xe4,0x68,0x60,0xd2,0x99,0x9b,0x5,0x65,0xba,0x4e,
  0x6d,0x46,0xca,0xd0,0x3d,0x74,0x1e,0x9b,0xdf,0x17,0x58,0xcb,0xdb,0xe1,0x47,0x28,
  0x28,0x62,0xcc,0x76,0x2c,0x53,0x53,0x12,0x1b,0x99,0xc6,0xfd,0x24,0x2e,0x4e,0x69,
  0xa,0xd6,0x40,0x40,0xfa,0x36,0xfe,0x7,0x37,0x2d,0xe2,0xb,0xeb,0x9e,0x39,0x8b,
  0x4a,0x40,0xa,0x9,0x58,0x20,0xc,0x43,0x73,0xd5,0x30,0x55,
  
};

static const unsigned char qt_resource_name[] = {
  // kxmlgui5
  0x0,0x8,
  0xf,0x42,0xe5,0x85,
  0x0,0x6b,
  0x0,0x78,0x0,0x6d,0x0,0x6c,0x0,0x67,0x0,0x75,0x0,0x69,0x0,0x35,
    // kigo
  0x0,0x4,
  0x0,0x7,0x1f,0xdf,
  0x0,0x6b,
  0x0,0x69,0x0,0x67,0x0,0x6f,
    // kigoui.rc
  0x0,0x9,
  0xe,0x6b,0x66,0x63,
  0x0,0x6b,
  0x0,0x69,0x0,0x67,0x0,0x6f,0x0,0x75,0x0,0x69,0x0,0x2e,0x0,0x72,0x0,0x63,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x1,0x9d,0x78,0xd4,0xdb,0x88,
  // :/kxmlgui5
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x1,0x9d,0x78,0xd4,0xdb,0x88,
  // :/kxmlgui5/kigo
  0x0,0x0,0x0,0x16,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x1,0x9d,0x78,0xd4,0xdb,0x88,
  // :/kxmlgui5/kigo/kigoui.rc
  0x0,0x0,0x0,0x24,0x0,0x4,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x9d,0x78,0xd4,0xdb,0x88,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#if defined(QT_INLINE_NAMESPACE)
inline namespace QT_NAMESPACE {
#elif defined(QT_NAMESPACE)
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);
bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#if defined(__ELF__) || defined(__APPLE__)
static inline unsigned char qResourceFeatureZstd()
{
    extern const unsigned char qt_resourceFeatureZstd;
    return qt_resourceFeatureZstd;
}
#else
unsigned char qResourceFeatureZstd();
#endif

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_kigo)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_kigo)()
{
    int version = 3;
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kigo)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kigo)()
{
    int version = 3;
    version += QT_RCC_PREPEND_NAMESPACE(qResourceFeatureZstd());
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (version, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

#ifdef __clang__
#   pragma clang diagnostic push
#   pragma clang diagnostic ignored "-Wexit-time-destructors"
#endif

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_kigo)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_kigo)(); }
   } dummy;
}

#ifdef __clang__
#   pragma clang diagnostic pop
#endif
