/********************************************************************************
** Form generated from reading UI file 'gamewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GAMEWIDGET_H
#define UI_GAMEWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GameWidget
{
public:
    QVBoxLayout *verticalLayout;
    QGridLayout *gridLayout;
    QLabel *label_5;
    QLabel *handicapLabel;
    QLabel *label_3;
    QLabel *komiLabel;
    QLabel *lastMoveLabel;
    QLabel *label;
    QLabel *moveLabel;
    QLabel *label_2;
    QLabel *currentPlayerImageLabel;
    QLabel *currentPlayerLabel;
    QLabel *whiteStoneImageLabel;
    QSpacerItem *verticalSpacer_3;
    QLabel *whiteNameLabel;
    QLabel *whiteCapturesLabel;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *verticalSpacer_2;
    QLabel *blackNameLabel;
    QLabel *blackStoneImageLabel;
    QLabel *blackCapturesLabel;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *finishButton;

    void setupUi(QWidget *GameWidget)
    {
        if (GameWidget->objectName().isEmpty())
            GameWidget->setObjectName("GameWidget");
        GameWidget->resize(201, 373);
        verticalLayout = new QVBoxLayout(GameWidget);
        verticalLayout->setObjectName("verticalLayout");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        label_5 = new QLabel(GameWidget);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_5, 3, 0, 1, 2);

        handicapLabel = new QLabel(GameWidget);
        handicapLabel->setObjectName("handicapLabel");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(handicapLabel->sizePolicy().hasHeightForWidth());
        handicapLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(handicapLabel, 3, 2, 1, 1);

        label_3 = new QLabel(GameWidget);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_3, 4, 0, 1, 2);

        komiLabel = new QLabel(GameWidget);
        komiLabel->setObjectName("komiLabel");
        sizePolicy.setHeightForWidth(komiLabel->sizePolicy().hasHeightForWidth());
        komiLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(komiLabel, 4, 2, 1, 1);

        lastMoveLabel = new QLabel(GameWidget);
        lastMoveLabel->setObjectName("lastMoveLabel");
        sizePolicy.setHeightForWidth(lastMoveLabel->sizePolicy().hasHeightForWidth());
        lastMoveLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(lastMoveLabel, 2, 2, 1, 1);

        label = new QLabel(GameWidget);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label, 2, 0, 1, 2);

        moveLabel = new QLabel(GameWidget);
        moveLabel->setObjectName("moveLabel");
        sizePolicy.setHeightForWidth(moveLabel->sizePolicy().hasHeightForWidth());
        moveLabel->setSizePolicy(sizePolicy);

        gridLayout->addWidget(moveLabel, 1, 2, 1, 1);

        label_2 = new QLabel(GameWidget);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(label_2, 1, 0, 1, 2);

        currentPlayerImageLabel = new QLabel(GameWidget);
        currentPlayerImageLabel->setObjectName("currentPlayerImageLabel");
        currentPlayerImageLabel->setMinimumSize(QSize(64, 64));
        currentPlayerImageLabel->setMaximumSize(QSize(164, 64));
        currentPlayerImageLabel->setFrameShape(QFrame::NoFrame);
        currentPlayerImageLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(currentPlayerImageLabel, 0, 0, 1, 2);

        currentPlayerLabel = new QLabel(GameWidget);
        currentPlayerLabel->setObjectName("currentPlayerLabel");

        gridLayout->addWidget(currentPlayerLabel, 0, 2, 1, 1);

        whiteStoneImageLabel = new QLabel(GameWidget);
        whiteStoneImageLabel->setObjectName("whiteStoneImageLabel");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(whiteStoneImageLabel->sizePolicy().hasHeightForWidth());
        whiteStoneImageLabel->setSizePolicy(sizePolicy1);
        whiteStoneImageLabel->setMinimumSize(QSize(48, 48));
        whiteStoneImageLabel->setMaximumSize(QSize(48, 48));

        gridLayout->addWidget(whiteStoneImageLabel, 6, 1, 2, 1);

        verticalSpacer_3 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_3, 5, 2, 1, 1);

        whiteNameLabel = new QLabel(GameWidget);
        whiteNameLabel->setObjectName("whiteNameLabel");

        gridLayout->addWidget(whiteNameLabel, 6, 2, 1, 1);

        whiteCapturesLabel = new QLabel(GameWidget);
        whiteCapturesLabel->setObjectName("whiteCapturesLabel");
        whiteCapturesLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(whiteCapturesLabel, 7, 2, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(0, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 6, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(verticalSpacer_2, 8, 2, 1, 1);

        blackNameLabel = new QLabel(GameWidget);
        blackNameLabel->setObjectName("blackNameLabel");

        gridLayout->addWidget(blackNameLabel, 9, 2, 1, 1);

        blackStoneImageLabel = new QLabel(GameWidget);
        blackStoneImageLabel->setObjectName("blackStoneImageLabel");
        sizePolicy1.setHeightForWidth(blackStoneImageLabel->sizePolicy().hasHeightForWidth());
        blackStoneImageLabel->setSizePolicy(sizePolicy1);
        blackStoneImageLabel->setMinimumSize(QSize(48, 48));
        blackStoneImageLabel->setMaximumSize(QSize(48, 48));

        gridLayout->addWidget(blackStoneImageLabel, 9, 1, 2, 1);

        blackCapturesLabel = new QLabel(GameWidget);
        blackCapturesLabel->setObjectName("blackCapturesLabel");
        blackCapturesLabel->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(blackCapturesLabel, 10, 2, 1, 1);


        verticalLayout->addLayout(gridLayout);

        verticalSpacer = new QSpacerItem(20, 1, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        finishButton = new QPushButton(GameWidget);
        finishButton->setObjectName("finishButton");
        finishButton->setEnabled(false);

        horizontalLayout->addWidget(finishButton);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(GameWidget);

        QMetaObject::connectSlotsByName(GameWidget);
    } // setupUi

    void retranslateUi(QWidget *GameWidget)
    {
        label_5->setText(tr2i18n("Handicap:", nullptr));
        handicapLabel->setText(tr2i18n("2", nullptr));
        label_3->setText(tr2i18n("Komi:", nullptr));
        komiLabel->setText(tr2i18n("0.5 Points", nullptr));
        lastMoveLabel->setText(QString());
        label->setText(tr2i18n("Last move:", nullptr));
        moveLabel->setText(QString());
        label_2->setText(tr2i18n("Move:", nullptr));
        currentPlayerImageLabel->setText(QString());
        currentPlayerLabel->setText(QString());
        whiteStoneImageLabel->setText(QString());
        whiteNameLabel->setText(tr2i18n("White Player", nullptr));
        whiteCapturesLabel->setText(tr2i18n("Captures:", nullptr));
        blackNameLabel->setText(tr2i18n("Black Player", nullptr));
        blackStoneImageLabel->setText(QString());
        blackCapturesLabel->setText(tr2i18n("Captures:", nullptr));
        finishButton->setText(tr2i18n("Finish Game", nullptr));
        (void)GameWidget;
    } // retranslateUi

};

namespace Ui {
    class GameWidget: public Ui_GameWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GAMEWIDGET_H

